@@ -20,7 +20,7 @@ automatic container width with opening animation
 ------------------------------------------------
 
 the class :class:`ContainerChildrenAutoWidthBehavior` determines the optimal width of a container widget, so that the
-text of any its children widgets is fully visible/displayed.
+text of any children widget is fully visible/displayed.
 
 the optimal container width is determined by increasing width of the container in iterations, which are implemented
 through a kivy :class:`~kivy.animation.Animation`. as soon as the texts of all children are fully displayed (or the
@@ -56,7 +56,7 @@ except ImportError:
     MAX_FONT_SIZE = 99
 
 
-__version__ = '0.3.18'
+__version__ = '0.3.19'
 
 
 class AutoFontSizeBehavior:
@@ -266,25 +266,24 @@ class ContainerChildrenAutoWidthBehavior:
 
         :param _args:           unused argument (to have compatible signature for Popup/ModalView and DropDown
                                 widgets passing the parent widget).
-        :param kwargs:          extra arguments that are removed before to be passed to the inheriting open method:
+        :param kwargs:          optional extra arguments:
 
-                                * 'open_width_animation': `False` will disable the `width` animation (default=True).
+                                * 'animation': `False` will disable the `width` and open()-animations (default=True).
         """
-        anim_width = kwargs.pop('open_width_animation', True)
-
         if not hasattr(super(), 'container'):
             self.container = getattr(self, '_container', self)  # Popup has _container attribute, BoxLayout=self
 
         if callable(getattr(super(), 'open', None)):    # call open method if exists in inheriting container/layout
             # noinspection PyUnresolvedReferences
-            super().open(*_args, **kwargs)      # pylint: disable=maybe-no-member
+            super().open(*_args, **kwargs)              # pylint: disable=maybe-no-member
 
-        if anim_width:
+        if kwargs.get('animation', True):
             container_max_width = Window.width - self.auto_width_window_padding
             self._width_anim = Animation(opacity=1.0, width=container_max_width,
                                          t='in_out_sine', d=self.auto_width_anim_duration)
             self._width_anim.bind(on_progress=self._open_width_progress)
             self._width_anim.bind(on_complete=self._on_complete_opened)
+            self.opacity = 0.0
             self.width = self.auto_width_start
             self._width_anim.start(self)
         else:
@@ -334,7 +333,7 @@ class SimpleAutoTickerBehavior:
     """ mix-in class to slide texture in a ping-pong-like-ticker animation, if too long to be displayed completely.
 
     if the `text` or `size` of the widget where this class get mixed in changes then this instance is first determining
-    the number of characters that can be displayed completely in this widget. this is done with an kivy animation. the
+    the number of characters that can be displayed completely in this widget. this is done with a kivy animation. the
     duration of this animation can be set via the property :attr:`auto_ticker_length_anim_duration`.
 
     to adjust the padding space between the widget border and their texture width, the property
